@@ -75,14 +75,9 @@ public:
     grid->SetSize(3,3);
 
     for (size_t i=1; i<=9; i++) {
-      wchar_t label[2];
-
-      label[0]=L'0'+i;
-      label[1]=L'\0';
-
       button=new Lum::Button();
       button->SetFlex(true,true);
-      button->SetText(label);
+      button->SetText(Lum::Base::NumberToWString(i));
       button->SetModel(models[i]);
 
       grid->SetObject((i-1)%3,(i-1)/3,button);
@@ -159,7 +154,6 @@ public:
     Lum::Grid       *grid;
     Lum::Panel      *panel;
     Lum::PopupGroup *container;
-    Lum::Toggle     *toggle;
 
     panel=new Lum::VPanel();
 
@@ -168,6 +162,8 @@ public:
     grid->SetSize(3,3);
 
     for (size_t i=0; i<=8; i++) {
+      Lum::Toggle *toggle;
+
       toggle=new Lum::Toggle();
       toggle->SetModel(models[i]);
       toggle->SetLabel(Lum::Base::NumberToWString(i+1));
@@ -226,6 +222,7 @@ GameArea::GameArea()
   SetPrefs(::prefs);
 
   SetCanFocus(true);
+  RequestFocus();
 
   finished->Set(true);
 }
